==> phydms-1.0.1.tar.gz: phydms-1.0.1/phydmslib/Bpp/bpp-phyl/src/Bpp/Phyl/NewLikelihood/AutoCorrelationSequenceEvolution.cpp <==
//
// File: AutoCorrelationSequenceEvolution.cpp
// Created by: Laurent Guéguen
// Created on: vendredi 1 mai 2015, à 21h 27
//

/*
   Copyright or © or Copr. Bio++ Development Team, (November 16, 2004)

   This software is a computer program whose purpose is to provide classes
   for phylogenetic data analysis.

   This software is governed by the CeCILL  license under French law and
   abiding by the rules of distribution of free software.  You can  use,
   modify and/ or redistribute the software under the terms of the CeCILL
   license as circulated by CEA, CNRS and INRIA at the following URL
   "http://www.cecill.info".

   As a counterpart to the access to the source code and  rights to copy,
   modify and redistribute granted by the license, users are provided only
   with a limited warranty  and the software's author,  the holder of the
   economic rights,  and the successive licensors  have only  limited
   liability.

   In this respect, the user's attention is drawn to the risks associated
   with loading,  using,  modifying and/or developing or reproducing the
   software by the user in light of its specific status of free software,
   that may mean  that it is complicated to manipulate,  and  that  also
   therefore means  that it is reserved for developers  and  experienced
   professionals having in-depth computer knowledge. Users are therefore
   encouraged to load and test the software's suitability as regards their
   requirements in conditions enabling the security of their systems and/or
   data to be ensured and,  more generally, to use and operate it in the
   same conditions as regards security.

   The fact that you are presently reading this means that you have had
   knowledge of the CeCILL license and that you accept its terms.
 */

#include "AutoCorrelationSequenceEvolution.h"

using namespace std;
using namespace bpp;

/******************************************************************************/

AutoCorrelationSequenceEvolution::AutoCorrelationSequenceEvolution(
  SubstitutionProcessCollection* processColl,
  std::vector<size_t>& nProc) :
  MultiProcessSequenceEvolution(processColl, nProc, "Autocorr."),
  hmmAlph_(),
  autoCorrTransMat_()
{
  hmmAlph_=std::auto_ptr<HmmProcessAlphabet>(new HmmProcessAlphabet(processColl_, nProc));

  autoCorrTransMat_=std::auto_ptr<AutoCorrelationTransitionMatrix>(new AutoCorrelationTransitionMatrix(hmmAlph_.get(),"Autocorr."));

  // initialize parameters:
  addParameters_(hmmAlph_->getParameters());
  addParameters_(autoCorrTransMat_->getParameters());
}


void AutoCorrelationSequenceEvolution::setNamespace(const std::string& nameSpace)
{
  deleteParameters_(hmmAlph_->getParameters().getParameterNames());
  deleteParameters_(autoCorrTransMat_->getParameters().getParameterNames());

  hmmAlph_->setNamespace(nameSpace);
  autoCorrTransMat_->setNamespace(nameSpace);

  addParameters_(hmmAlph_->getParameters());
  addParameters_(autoCorrTransMat_->getParameters());
}


void AutoCorrelationSequenceEvolution::fireParameterChanged(const ParameterList& parameters)
{
  MultiProcessSequenceEvolution::fireParameterChanged(parameters);

  hmmAlph_->matchParametersValues(parameters);
  autoCorrTransMat_->matchParametersValues(parameters);
}


ParameterList AutoCorrelationSequenceEvolution::getNonDerivableParameters() const
{
  ParameterList pl = MultiProcessSequenceEvolution::getNonDerivableParameters();
  pl.addParameters(hmmAlph_->getParameters());
  pl.addParameters(autoCorrTransMat_->getParameters());

  return pl;
}

==> phydms-1.2.0.tar.gz: phydms-1.2.0/phydmslib/Bpp/bpp-phyl/src/Bpp/Phyl/NewLikelihood/AutoCorrelationSequenceEvolution.cpp <==
//
// File: AutoCorrelationSequenceEvolution.cpp
// Created by: Laurent Guéguen
// Created on: vendredi 1 mai 2015, à 21h 27
//

/*
   Copyright or © or Copr. Bio++ Development Team, (November 16, 2004)

   This software is a computer program whose purpose is to provide classes
   for phylogenetic data analysis.

   This software is governed by the CeCILL  license under French law and
   abiding by the rules of distribution of free software.  You can  use,
   modify and/ or redistribute the software under the terms of the CeCILL
   license as circulated by CEA, CNRS and INRIA at the following URL
   "http://www.cecill.info".

   As a counterpart to the access to the source code and  rights to copy,
   modify and redistribute granted by the license, users are provided only
   with a limited warranty  and the software's author,  the holder of the
   economic rights,  and the successive licensors  have only  limited
   liability.

   In this respect, the user's attention is drawn to the risks associated
   with loading,  using,  modifying and/or developing or reproducing the
   software by the user in light of its specific status of free software,
   that may mean  that it is complicated to manipulate,  and  that  also
   therefore means  that it is reserved for developers  and  experienced
   professionals having in-depth computer knowledge. Users are therefore
   encouraged to load and test the software's suitability as regards their
   requirements in conditions enabling the security of their systems and/or
   data to be ensured and,  more generally, to use and operate it in the
   same conditions as regards security.

   The fact that you are presently reading this means that you have had
   knowledge of the CeCILL license and that you accept its terms.
 */

#include "AutoCorrelationSequenceEvolution.h"

using namespace std;
using namespace bpp;

/******************************************************************************/

AutoCorrelationSequenceEvolution::AutoCorrelationSequenceEvolution(
  SubstitutionProcessCollection* processColl,
  std::vector<size_t>& nProc) :
  MultiProcessSequenceEvolution(processColl, nProc, "AutoCorr."),
  hmmAlph_(),
  autoCorrTransMat_()
{
  hmmAlph_=std::auto_ptr<HmmProcessAlphabet>(new HmmProcessAlphabet(processColl_, nProc));

  autoCorrTransMat_=std::auto_ptr<AutoCorrelationTransitionMatrix>(new AutoCorrelationTransitionMatrix(hmmAlph_.get(),"AutoCorr."));

  // initialize parameters:
  addParameters_(hmmAlph_->getParameters());
  addParameters_(autoCorrTransMat_->getParameters());
}


void AutoCorrelationSequenceEvolution::setNamespace(const std::string& nameSpace)
{
  deleteParameters_(hmmAlph_->getParameters().getParameterNames());
  deleteParameters_(autoCorrTransMat_->getParameters().getParameterNames());

  hmmAlph_->setNamespace(nameSpace);
  autoCorrTransMat_->setNamespace(nameSpace);

  addParameters_(hmmAlph_->getParameters());
  addParameters_(autoCorrTransMat_->getParameters());
}


void AutoCorrelationSequenceEvolution::fireParameterChanged(const ParameterList& parameters)
{
  MultiProcessSequenceEvolution::fireParameterChanged(parameters);

  hmmAlph_->matchParametersValues(parameters);
  autoCorrTransMat_->matchParametersValues(parameters);
}
